# Description

*Describe your feature. What does it do? How does it work? If applicable mention an issue on the issue tracker*

# Checklist

- [ ] The code follows the relevant coding guidelines
- [ ] The code generates no new warnings
- [ ] The code is appropriately documented
- [ ] The code is tested to prove its function
- [ ] The feature branch is rebased on the current state of the `main` branch
- [ ] I updated the change log if relevant
- [ ] I give permission that the Eradiate project may redistribute my contributions under the terms of its license
